@@ -75,9 +75,7 @@ from bitmovin_api_sdk.models.analytics_greater_than_filter import AnalyticsGreat
 from bitmovin_api_sdk.models.analytics_greater_than_or_equal_filter import AnalyticsGreaterThanOrEqualFilter
 from bitmovin_api_sdk.models.analytics_http_request import AnalyticsHttpRequest
 from bitmovin_api_sdk.models.analytics_http_request_type import AnalyticsHttpRequestType
-from bitmovin_api_sdk.models.analytics_impression_details import AnalyticsImpressionDetails
 from bitmovin_api_sdk.models.analytics_impression_list_item import AnalyticsImpressionListItem
-from bitmovin_api_sdk.models.analytics_impression_sample import AnalyticsImpressionSample
 from bitmovin_api_sdk.models.analytics_impressions_query import AnalyticsImpressionsQuery
 from bitmovin_api_sdk.models.analytics_impressions_response import AnalyticsImpressionsResponse
 from bitmovin_api_sdk.models.analytics_in_filter import AnalyticsInFilter
@@ -112,7 +110,6 @@ from bitmovin_api_sdk.models.analytics_s3_role_based_output import AnalyticsS3Ro
 from bitmovin_api_sdk.models.analytics_stddev_query_request import AnalyticsStddevQueryRequest
 from bitmovin_api_sdk.models.analytics_sum_query_request import AnalyticsSumQueryRequest
 from bitmovin_api_sdk.models.analytics_variance_query_request import AnalyticsVarianceQueryRequest
-from bitmovin_api_sdk.models.analytics_video_start_failed_reason import AnalyticsVideoStartFailedReason
 from bitmovin_api_sdk.models.analytics_virtual_license import AnalyticsVirtualLicense
 from bitmovin_api_sdk.models.analytics_virtual_license_licenses_list_item import AnalyticsVirtualLicenseLicensesListItem
 from bitmovin_api_sdk.models.analytics_virtual_license_request import AnalyticsVirtualLicenseRequest
@@ -155,6 +152,10 @@ from bitmovin_api_sdk.models.azure_account_region_settings import AzureAccountRe
 from bitmovin_api_sdk.models.azure_cloud_region import AzureCloudRegion
 from bitmovin_api_sdk.models.azure_input import AzureInput
 from bitmovin_api_sdk.models.azure_output import AzureOutput
+from bitmovin_api_sdk.models.azure_speech_services_credentials import AzureSpeechServicesCredentials
+from bitmovin_api_sdk.models.azure_speech_to_captions_filter import AzureSpeechToCaptionsFilter
+from bitmovin_api_sdk.models.azure_speech_to_captions_profanity import AzureSpeechToCaptionsProfanity
+from bitmovin_api_sdk.models.azure_speech_to_captions_settings import AzureSpeechToCaptionsSettings
 from bitmovin_api_sdk.models.b_adapt import BAdapt
 from bitmovin_api_sdk.models.backup_srt_inputs import BackupSrtInputs
 from bitmovin_api_sdk.models.basic_media_info import BasicMediaInfo
@@ -211,6 +212,7 @@ from bitmovin_api_sdk.models.color_transfer import ColorTransfer
 from bitmovin_api_sdk.models.concatenation_input_configuration import ConcatenationInputConfiguration
 from bitmovin_api_sdk.models.concatenation_input_stream import ConcatenationInputStream
 from bitmovin_api_sdk.models.condition import Condition
+from bitmovin_api_sdk.models.condition_attribute import ConditionAttribute
 from bitmovin_api_sdk.models.condition_operator import ConditionOperator
 from bitmovin_api_sdk.models.condition_type import ConditionType
 from bitmovin_api_sdk.models.conform_filter import ConformFilter
@@ -328,7 +330,6 @@ from bitmovin_api_sdk.models.dts_x_audio_configuration import DtsXAudioConfigura
 from bitmovin_api_sdk.models.dts_x_channel_layout import DtsXChannelLayout
 from bitmovin_api_sdk.models.dvb_subtitle_configuration import DvbSubtitleConfiguration
 from bitmovin_api_sdk.models.dvb_subtitle_input_stream import DvbSubtitleInputStream
-from bitmovin_api_sdk.models.dvb_teletext_input_stream import DvbTeletextInputStream
 from bitmovin_api_sdk.models.eac3_audio_configuration import Eac3AudioConfiguration
 from bitmovin_api_sdk.models.ebu_r128_single_pass_filter import EbuR128SinglePassFilter
 from bitmovin_api_sdk.models.egress_category import EgressCategory
@@ -466,6 +467,7 @@ from bitmovin_api_sdk.models.live_dash_manifest import LiveDashManifest
 from bitmovin_api_sdk.models.live_encoding import LiveEncoding
 from bitmovin_api_sdk.models.live_encoding_codec import LiveEncodingCodec
 from bitmovin_api_sdk.models.live_encoding_event_name import LiveEncodingEventName
+from bitmovin_api_sdk.models.live_encoding_heartbeat_webhook import LiveEncodingHeartbeatWebhook
 from bitmovin_api_sdk.models.live_encoding_options_statistics import LiveEncodingOptionsStatistics
 from bitmovin_api_sdk.models.live_encoding_stats import LiveEncodingStats
 from bitmovin_api_sdk.models.live_encoding_stats_event import LiveEncodingStatsEvent
@@ -536,6 +538,7 @@ from bitmovin_api_sdk.models.packed_audio_muxing_information import PackedAudioM
 from bitmovin_api_sdk.models.padding_duration_unit import PaddingDurationUnit
 from bitmovin_api_sdk.models.padding_sequence import PaddingSequence
 from bitmovin_api_sdk.models.pagination_response import PaginationResponse
+from bitmovin_api_sdk.models.passthrough_audio_configuration import PassthroughAudioConfiguration
 from bitmovin_api_sdk.models.passthrough_mode import PassthroughMode
 from bitmovin_api_sdk.models.pcm_audio_configuration import PcmAudioConfiguration
 from bitmovin_api_sdk.models.pcm_channel_layout import PcmChannelLayout
@@ -581,6 +584,8 @@ from bitmovin_api_sdk.models.progressive_muxing_information import ProgressiveMu
 from bitmovin_api_sdk.models.progressive_ts_muxing import ProgressiveTsMuxing
 from bitmovin_api_sdk.models.progressive_ts_muxing_information import ProgressiveTsMuxingInformation
 from bitmovin_api_sdk.models.progressive_ts_muxing_information_byte_ranges import ProgressiveTsMuxingInformationByteRanges
+from bitmovin_api_sdk.models.progressive_wav_muxing import ProgressiveWavMuxing
+from bitmovin_api_sdk.models.progressive_wav_muxing_information import ProgressiveWavMuxingInformation
 from bitmovin_api_sdk.models.progressive_webm_muxing import ProgressiveWebmMuxing
 from bitmovin_api_sdk.models.progressive_webm_muxing_information import ProgressiveWebmMuxingInformation
 from bitmovin_api_sdk.models.progressive_webm_muxing_manifest_type import ProgressiveWebmMuxingManifestType
@@ -594,6 +599,7 @@ from bitmovin_api_sdk.models.raw_id3_tag import RawId3Tag
 from bitmovin_api_sdk.models.redundant_rtmp_input import RedundantRtmpInput
 from bitmovin_api_sdk.models.reprioritize_encoding_request import ReprioritizeEncodingRequest
 from bitmovin_api_sdk.models.reschedule_encoding_request import RescheduleEncodingRequest
+from bitmovin_api_sdk.models.reset_live_manifest_time_shift import ResetLiveManifestTimeShift
 from bitmovin_api_sdk.models.resource_limit import ResourceLimit
 from bitmovin_api_sdk.models.resource_limit_container import ResourceLimitContainer
 from bitmovin_api_sdk.models.resource_type import ResourceType
@@ -697,6 +703,7 @@ from bitmovin_api_sdk.models.start_live_encoding_request import StartLiveEncodin
 from bitmovin_api_sdk.models.start_manifest_request import StartManifestRequest
 from bitmovin_api_sdk.models.static_ip import StaticIp
 from bitmovin_api_sdk.models.static_ip_status import StaticIpStatus
+from bitmovin_api_sdk.models.static_rtmp_ingest_point import StaticRtmpIngestPoint
 from bitmovin_api_sdk.models.statistics import Statistics
 from bitmovin_api_sdk.models.statistics_per_label import StatisticsPerLabel
 from bitmovin_api_sdk.models.statistics_per_muxing import StatisticsPerMuxing
@@ -713,6 +720,12 @@ from bitmovin_api_sdk.models.stream_info import StreamInfo
 from bitmovin_api_sdk.models.stream_infos import StreamInfos
 from bitmovin_api_sdk.models.stream_infos_details import StreamInfosDetails
 from bitmovin_api_sdk.models.stream_input import StreamInput
+from bitmovin_api_sdk.models.stream_key import StreamKey
+from bitmovin_api_sdk.models.stream_key_configuration import StreamKeyConfiguration
+from bitmovin_api_sdk.models.stream_key_configuration_type import StreamKeyConfigurationType
+from bitmovin_api_sdk.models.stream_key_status import StreamKeyStatus
+from bitmovin_api_sdk.models.stream_key_type import StreamKeyType
+from bitmovin_api_sdk.models.stream_keys_unassign_action import StreamKeysUnassignAction
 from bitmovin_api_sdk.models.stream_metadata import StreamMetadata
 from bitmovin_api_sdk.models.stream_mode import StreamMode
 from bitmovin_api_sdk.models.stream_per_title_fixed_resolution_and_bitrate_settings import StreamPerTitleFixedResolutionAndBitrateSettings
@@ -720,7 +733,9 @@ from bitmovin_api_sdk.models.stream_per_title_settings import StreamPerTitleSett
 from bitmovin_api_sdk.models.stream_selection_mode import StreamSelectionMode
 from bitmovin_api_sdk.models.streams_ad_config_ad import StreamsAdConfigAd
 from bitmovin_api_sdk.models.streams_ad_config_response import StreamsAdConfigResponse
-from bitmovin_api_sdk.models.streams_content_protection_response import StreamsContentProtectionResponse
+from bitmovin_api_sdk.models.streams_domain_restriction_create_request import StreamsDomainRestrictionCreateRequest
+from bitmovin_api_sdk.models.streams_domain_restriction_response import StreamsDomainRestrictionResponse
+from bitmovin_api_sdk.models.streams_domain_restriction_update_request import StreamsDomainRestrictionUpdateRequest
 from bitmovin_api_sdk.models.streams_encoding_profile import StreamsEncodingProfile
 from bitmovin_api_sdk.models.streams_live_create_request import StreamsLiveCreateRequest
 from bitmovin_api_sdk.models.streams_live_life_cycle import StreamsLiveLifeCycle
