@@ -40,6 +40,7 @@ class CloudRegion(Enum):
     GOOGLE_SOUTHAMERICA_EAST_1 = "GOOGLE_SOUTHAMERICA_EAST_1"
     GOOGLE_US_EAST_4 = "GOOGLE_US_EAST_4"
     GOOGLE_US_WEST_2 = "GOOGLE_US_WEST_2"
+    GOOGLE_ME_CENTRAL_2 = "GOOGLE_ME_CENTRAL_2"
     AZURE_ASIA_EAST = "AZURE_ASIA_EAST"
     AZURE_ASIA_SOUTHEAST = "AZURE_ASIA_SOUTHEAST"
     AZURE_AUSTRALIA_EAST = "AZURE_AUSTRALIA_EAST"
@@ -62,10 +63,14 @@ class CloudRegion(Enum):
     AZURE_US_WEST = "AZURE_US_WEST"
     AZURE_US_WEST2 = "AZURE_US_WEST2"
     AZURE_US_SOUTH_CENTRAL = "AZURE_US_SOUTH_CENTRAL"
+    AZURE_US_NORTH_CENTRAL = "AZURE_US_NORTH_CENTRAL"
+    AZURE_UK_SOUTH = "AZURE_UK_SOUTH"
     AKAMAI_BR_GRU = "AKAMAI_BR_GRU"
     AKAMAI_FR_PAR = "AKAMAI_FR_PAR"
     AKAMAI_JP_OSA = "AKAMAI_JP_OSA"
     AKAMAI_US_SEA = "AKAMAI_US_SEA"
+    OCI_EU_FRANKFURT_1 = "OCI_EU_FRANKFURT_1"
+    OCI_US_ASHBURN_1 = "OCI_US_ASHBURN_1"
     NORTH_AMERICA = "NORTH_AMERICA"
     SOUTH_AMERICA = "SOUTH_AMERICA"
     EUROPE = "EUROPE"
