@@ -6,6 +6,7 @@ from bitmovin_api_sdk.common import BaseApi, BitmovinApiLoggerBase
 from bitmovin_api_sdk.common.poscheck import poscheck_except
 from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.finished.finished_api import FinishedApi
 from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.error.error_api import ErrorApi
+from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.live_encoding_heartbeat.live_encoding_heartbeat_api import LiveEncodingHeartbeatApi
 from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.transfer_error.transfer_error_api import TransferErrorApi
 from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.live_input_stream_changed.live_input_stream_changed_api import LiveInputStreamChangedApi
 from bitmovin_api_sdk.notifications.webhooks.encoding.encodings.encoding_status_changed.encoding_status_changed_api import EncodingStatusChangedApi
@@ -37,6 +38,13 @@ class EncodingsApi(BaseApi):
             logger=logger
         )
 
+        self.live_encoding_heartbeat = LiveEncodingHeartbeatApi(
+            api_key=api_key,
+            tenant_org_id=tenant_org_id,
+            base_url=base_url,
+            logger=logger
+        )
+
         self.transfer_error = TransferErrorApi(
             api_key=api_key,
             tenant_org_id=tenant_org_id,
